FormBlocStep class

A material step used in Stepper. The step can have a title and subtitle, an icon within its circle, some content and a state that governs its styling.

Annotations

Constructors

FormBlocStep({required Widget title, Widget? subtitle, required Widget content, StepState state = StepState.indexed, bool? isActive})
const

Properties

content Widget
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StepState
final
subtitle Widget?
final
title Widget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited