FormBlocStep class
A material step used in Stepper. The step can have a title and subtitle,
an icon within its circle, some content and a state that governs its
styling.
- Annotations
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited